/*
 * Example for GainAMP click
 *
 * Date         Jan 2017
 * Author       Marton B.
 * Copyright    GNU Public License v2
 *
 * Test configuration AVR :
 *  MCU           :	ATMEGA32
 *  Dev. Board    :	EasyAVR v7
 *  SW            :	mikroC PRO for AVR v6.1.1
 *
 * Include example.pld file in your project.
 *
 ******************************************************************************/

#include "gain_amp.h"

#define PIN_DIR_IN 0
#define PIN_DIR_OUT 1
#define PIN_ALL_DIR_OUT 0xFF


sbit GAIN_AMP_CS at PORTA5_bit;
sbit GAIN_AMP_SHDN at PORTA6_bit;

sbit GAIN_AMP_CS_DIR at DDA5_bit;
sbit GAIN_AMP_SHDN_DIR at DDA6_bit;


static uint8_t gain;
static uint8_t byte;

static void system_init( void );


static void system_init( void )
{
    GAIN_AMP_CS_DIR = PIN_DIR_OUT;
    GAIN_AMP_SHDN_DIR = PIN_DIR_OUT;
    GAIN_AMP_CS = 1;

    // Input pins for buttons.
    DDA1_bit = PIN_DIR_IN;
    DDA0_bit = PIN_DIR_IN;

    // Output pins for displaying contol byte.
    DDRC = PIN_ALL_DIR_OUT;

    // Initialize SPI.
    SPI1_Init_Advanced( _SPI_MASTER, _SPI_FCY_DIV32, _SPI_CLK_HI_LEADING );

    // Initialize GainAMP module.
    gain_amp_init( SPI1_Write );

    gain = 0;
}

void main()
{
    system_init();

    gain_amp_set(GAIN_AMP_NOMINAL_0, GAIN_AMP_SW_SHUTDOWN);

    while( 1 )
    {
        if(Button(&PINA, 1, 100, 1))
        {
            byte = gain_amp_set(++gain & 0x07, GAIN_AMP_SW_SHUTDOWN);
            PORTC = byte;
        }
        if(Button(&PINA, 0, 100, 1))
        {
            byte = gain_amp_set(--gain & 0x07, GAIN_AMP_SW_SHUTDOWN);
            PORTC = byte;
        }
    }
}

/************************************************************ END OF FILE *****/